==> glademm_0.6.4.orig.tar.gz: glademm-0.6.4/src/writers/ctree.cc <==
// $Id: ctree.cc,v 1.3 2001/10/11 14:07:24 christof Exp $
/*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
 *  Copyright (C) 2001  Adolf Petig GmbH & Co. KG, written by Christof Petig
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
// copied from clist -- might work

#include "container.hh"

class Gtk_CTree : public Gtk_Container
{public:
	typedef Gtk_Container Parent;
	virtual const std::string TypeName(const Widget &w) const;
	virtual const std::string IncludeName(const Widget &w) const;
	Gtk_CTree(bool base_class_init=true);
	virtual void ConstructionArgs(const Widget &w, CxxFile &f) const;
	virtual bool NeedExplicitCtor(const Widget &w) const
	{  return true; }
	virtual bool DefaultSeparateClass(const Widget &w) const
	{  return false; }
	void Configure(const Widget &w, CxxFile &f,const std::string &instance) const;
	const std::string SignalHandlerArgs(const Widget &w,const std::string &signal,std::string &rettype) const;
	virtual Subwidget IsSubwidget(const Widget &parent,const Widget &w2) const;
	virtual const std::string InternalInstance(const Widget &parent,const Widget &w2) const;
};

#include "../strsep.h"

static Gtk_CTree Gtk_CTree(false);

const std::string Gtk_CTree::TypeName(const Widget &w) const
{  return GtkPrefix()+"CTree";
}

const std::string Gtk_CTree::IncludeName(const Widget &w) const
{  return "gtk--/ctree.h";
}

Gtk_CTree::Gtk_CTree(bool base_class_init)
{  if (!base_class_init) Writer["GtkCTree"]=this;
}

void Gtk_CTree::ConstructionArgs(const Widget &w, CxxFile &f) const
{  f.FunctionArg() << w.getInt("columns",3);
           // 2do: look for columns and pass them ???
}

void Gtk_CTree::Configure(const Widget &w, CxxFile &f,const std::string &instance) const
{  Parent::Configure(w,f,instance);
   std::string selection_mode=w.getString("selection_mode","GTK_SELECTION_SINGLE");
   bool show_titles=w.getBool("show_titles",true);
   std::string shadow_type=w.getString("shadow_type","GTK_SHADOW_IN");
   std::string hscrollbar_policy=w.getString("hscrollbar_policy","GTK_POLICY_AUTOMATIC");
   std::string vscrollbar_policy=w.getString("vscrollbar_policy","GTK_POLICY_AUTOMATIC");
   std::string column_widths=w.getString("column_widths","20");
   char *buffer=(char*)alloca(column_widths.size()+1);
   memcpy(buffer,column_widths.c_str(),column_widths.size()+1);
   char *stringp=buffer;
   // 2do: Tooltips
      
   int i=0;
   for (Widget::const_iterator ch=w.begin();ch!=w.end();++ch,++i)
   {  char *token=strsep(&stringp,",");
      int column_width=!token?20:atoi(token);
      if ((*ch).Class()=="GtkLabel")
      {  std::string label=(*ch).getString("label","");
         if (label!="")
            f.Statement() << instance << "set_column_title(" << i << ", " 
              	<< Configuration.Translatable(label) << ')';
         std::string justify=(*ch).getString("justify","GTK_JUSTIFY_LEFT");
         if (justify!="GTK_JUSTIFY_LEFT")
            f.Statement() << instance << "set_column_justification(" << i << ", "
              << justify << ')';
         f.Statement() << instance << "set_column_width(" << i << ", " << column_width << ')';
      }
      else
         std::cerr << "Gtk_CTree::Configure: can't handle widget class "
              << (*ch).Class() << " as title\n";
   }
   if (selection_mode!="GTK_SELECTION_SINGLE")
      f.Statement() << instance << "set_selection_mode(" << selection_mode << ')';
   if (show_titles)
      f.Statement() << instance << "column_titles_show()";
}

Subwidget Gtk_CTree::IsSubwidget(const Widget &parent,const Widget &w2) const
{  if (w2.ChildName()=="CTree:title" && w2.Class()=="GtkLabel") return is_Subwidget_all;
//	&& w2.getString("cxx_visibility","private")=="private") 
   return not_Subwidget;
}

const std::string Gtk_CTree::SignalHandlerArgs(const Widget &w,const std::string &signal,std::string &rettype) const
{  if (signal=="select_row" || signal=="unselect_row") 
      return "gint row, gint column, GdkEvent *event";
   else if (signal=="resize_column")
      return "gint column, gint width";
   else if (signal=="extend_selection")
      return "GtkScrollType scroll_type, gfloat position, gboolean auto_start_selection";
   else if (signal=="scroll_horizontal" || signal=="scroll_vertical")
      return "GtkScrollType scroll_type, gfloat position";
   else if (signal=="resync_selection")
      return "GdkEvent *event";
   else if (signal=="row_move")
      return "gint source_row, gint dest_row";
   else if (signal=="click_column")
      return "gint column";
   return Parent::SignalHandlerArgs(w,signal,rettype);
}

const std::string Gtk_CTree::InternalInstance(const Widget &parent,const Widget &w2) const
{
#warning Fixme for non standard column headers (internal widgets)
   return Parent::InternalInstance(parent,w2);
}

==> glademm_2.0.0.1.orig.tar.gz: glademm-2.0.0.1/src/writers/ctree.cc <==
// $Id: ctree.cc,v 1.10 2003/01/06 07:27:14 christof Exp $
/*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
 *  Copyright (C) 2001  Adolf Petig GmbH & Co. KG, written by Christof Petig
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
// copied from clist -- might work

#include "container.hh"

class Gtk_CTree : public Gtk_Container
{public:
	typedef Gtk_Container Parent;
	virtual const std::string TypeName(const Widget &w) const;
	virtual const std::string IncludeName(const Widget &w) const;
	Gtk_CTree(bool base_class_init=true);
	virtual void ConstructionArgs(const Widget &w, CxxFile &f) const;
	virtual bool NeedExplicitCtor(const Widget &w) const
	{  return true; }
	virtual bool DefaultSeparateClass(const Widget &w) const
	{  return false; }
	void Configure(const Widget &w, CxxFile &f,const std::string &instance) const;
	const std::string SignalHandlerArgs(const Widget &w,const std::string &signal,std::string &rettype,std::string &scope) const;
	virtual Subwidget IsSubwidget(const Widget &parent,const Widget &w2) const;
	virtual const std::string InternalInstance(const Widget &parent,const Widget &w2) const;
};

#include "../strsep.h"

static Gtk_CTree Gtk_CTree(false);

const std::string Gtk_CTree::TypeName(const Widget &w) const
{  return GtkPrefix()+"CTree";
}

const std::string Gtk_CTree::IncludeName(const Widget &w) const
{  return Configuration.GtkmmIncludePath()+"ctree.h";
}

Gtk_CTree::Gtk_CTree(bool base_class_init)
{  if (!base_class_init) Writer["GtkCTree"]=this;
}

void Gtk_CTree::ConstructionArgs(const Widget &w, CxxFile &f) const
{  f.FunctionArg() << w.getIntProperty("columns",3);
           // 2do: look for columns and pass them ???
}

void Gtk_CTree::Configure(const Widget &w, CxxFile &f,const std::string &instance) const
{  Parent::Configure(w,f,instance);
   std::string column_widths=w.getProperty("column_widths","20");
#ifdef __MINGW32__
   char buffer[column_widths.size()+1];
#else   
   char *buffer=(char*)alloca(column_widths.size()+1);
#endif   
   memcpy(buffer,column_widths.c_str(),column_widths.size()+1);
   char *stringp=buffer;
   // 2do: Tooltips
      
   int i=0;
   for (Widget::const_iterator ch=w.begin();ch!=w.end();++ch,++i)
   {  char *token=strsep(&stringp,",");
      int column_width=!token?20:atoi(token);
      if ((*ch).Class()=="GtkLabel")
      {  std::string label=(*ch).getProperty("label","");
         if (!label.empty())
            f.Statement() << instance << "set_column_title(" << i << ", " 
              	<< Configuration.Translatable(label) << ')';
         std::string justify=(*ch).getProperty("justify","GTK_JUSTIFY_LEFT");
         if (justify!="GTK_JUSTIFY_LEFT")
            f.Statement() << instance << "set_column_justification(" << i << ", "
              << justify << ')';
         f.Statement() << instance << "set_column_width(" << i << ", " << column_width << ')';
      }
      else
         std::cerr << "Gtk_CTree::Configure: can't handle widget class "
              << (*ch).Class() << " as title\n";
   }
   WriteEnumPropertyNS(w,f,instance, "selection_mode");
   WriteEnumPropertyNS(w,f,instance, "shadow_type");
   WriteBoolProp_2Fun(w,f,instance, "show_titles", "column_titles_hide()", "column_titles_show()");
}

Subwidget Gtk_CTree::IsSubwidget(const Widget &parent,const Widget &w2) const
{  if (w2.ChildName()=="CTree:title" && w2.Class()=="GtkLabel") return is_Subwidget_all;
//	&& w2.getProperty("cxx_visibility","private")=="private") 
   return not_Subwidget;
}

const std::string Gtk_CTree::SignalHandlerArgs(const Widget &w,const std::string &signal,std::string &rettype,std::string &scope) const
{  scope=Gtk_CTree::TypeName(w);
   if (signal=="select_row" || signal=="unselect_row") 
      return "gint row, gint column, GdkEvent *event";
   else if (signal=="resize_column")
      return "gint column, gint width";
   else if (signal=="extend_selection")
      return "GtkScrollType scroll_type, gfloat position, gboolean auto_start_selection";
   else if (signal=="scroll_horizontal" || signal=="scroll_vertical")
      return "GtkScrollType scroll_type, gfloat position";
   else if (signal=="resync_selection")
      return "GdkEvent *event";
   else if (signal=="row_move")
      return "gint source_row, gint dest_row";
   else if (signal=="click_column")
      return "gint column";
   return Parent::SignalHandlerArgs(w,signal,rettype,scope);
}

const std::string Gtk_CTree::InternalInstance(const Widget &parent,const Widget &w2) const
{
#warning Fixme for non standard column headers (internal widgets)
   return Parent::InternalInstance(parent,w2);
}
